@@ -19,6 +19,8 @@ BEGIN { extends 'Types::Standard' };
 
 my $LOADABLE_CLASS_ERROR;
 
+$Error::TypeTiny::CarpInternal{ 'Method::Generate::Accessor' }++;
+$Error::TypeTiny::CarpInternal{ 'Method::Generate::Constructor' }++;
 $Error::TypeTiny::CarpInternal{ 'Sub::Quote' }++;
 $Error::TypeTiny::CarpInternal{ 'Unexpected::TraitFor::Throwing' }++;
 
@@ -237,7 +239,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2017 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
